package com.ruoyi.ss.msgLog.mapper;

import com.ruoyi.ss.msgLog.domain.MsgLog;

import java.util.List;

/**
 * 短信日志Mapper接口
 *
 * @author qiuzhenzhen
 * @date 2024-07-24
 */
public interface MsgLogMapper
{
    /**
     * 查询短信日志
     *
     * @param id 短信日志主键
     * @return 短信日志
     */
    public MsgLog selectEtMsgLogById(Long id);

    /**
     * 查询短信日志列表
     *
     * @param eMsgLog 短信日志
     * @return 短信日志集合
     */
    public List<MsgLog> selectEtMsgLogList(MsgLog eMsgLog);

    /**
     * 新增短信日志
     *
     * @param eMsgLog 短信日志
     * @return 结果
     */
    public int insertEtMsgLog(MsgLog eMsgLog);

    /**
     * 修改短信日志
     *
     * @param eMsgLog 短信日志
     * @return 结果
     */
    public int updateEtMsgLog(MsgLog eMsgLog);

    /**
     * 删除短信日志
     *
     * @param id 短信日志主键
     * @return 结果
     */
    public int deleteEtMsgLogById(Long id);

    /**
     * 批量删除短信日志
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEtMsgLogByIds(Long[] ids);
}
